@@ -45,20 +45,15 @@ anomaly.anomaly_score({"src_bytes": 350})
 
 import math
 
-try:
-    from pandas import DataFrame
-    PANDAS_READY = True
-except ImportError:
-    PANDAS_READY = False
-
 from bigml.predicate_utils.utils import OPERATOR_CODE, PREDICATE_INFO_LENGTH
 from bigml.predicate_utils.utils import apply_predicates
 from bigml.api import FINISHED
 from bigml.api import get_status, get_api_connection, get_anomaly_id
 from bigml.basemodel import get_resource_dict
 from bigml.modelfields import ModelFields, NUMERIC
-from bigml.util import cast, use_cache, load
-from bigml.constants import OUT_NEW_HEADERS
+from bigml.util import cast, use_cache, load, get_data_format, \
+    get_formatted_data, format_data, get_data_transformations
+from bigml.constants import OUT_NEW_HEADERS, INTERNAL, DECIMALS
 
 
 DEPTH_FACTOR = 0.5772156649
@@ -202,7 +197,9 @@ class Anomaly(ModelFields):
             return
 
         self.resource_id = None
-        self.dataset_id = None
+        self.name = None
+        self.description = None
+        self.parent_id = None
         self.sample_size = None
         self.input_fields = None
         self.default_numeric_value = None
@@ -217,18 +214,23 @@ class Anomaly(ModelFields):
 
         if 'object' in anomaly and isinstance(anomaly['object'], dict):
             anomaly = anomaly['object']
-            self.dataset_id = anomaly.get('dataset')
+        try:
+            self.parent_id = anomaly.get('dataset')
+            self.name = anomaly.get("name")
+            self.description = anomaly.get("description")
             self.sample_size = anomaly.get('sample_size')
             self.input_fields = anomaly.get('input_fields')
             self.default_numeric_value = anomaly.get('default_numeric_value')
             self.normalize_repeats = anomaly.get('normalize_repeats', False)
             self.id_fields = anomaly.get('id_fields', [])
+        except AttributeError:
+            raise ValueError("Failed to find the expected "
+                             "JSON structure. Check your arguments.")
 
         if 'model' in anomaly and isinstance(anomaly['model'], dict):
             ModelFields.__init__(
                 self, anomaly['model'].get('fields'),
                 missing_tokens=anomaly['model'].get('missing_tokens'))
-
             self.mean_depth = anomaly['model'].get('mean_depth')
             self.normalization_factor = anomaly['model'].get(
                 'normalization_factor')
@@ -263,6 +265,13 @@ class Anomaly(ModelFields):
             return min(self.mean_depth, default_depth)
         return None
 
+    def data_transformations(self):
+        """Returns the pipeline transformations previous to the modeling
+        step as a pipeline, so that they can be used in local predictions.
+        Avoiding to set it in a Mixin to maintain the current dump function.
+        """
+        return get_data_transformations(self.resource_id, self.parent_id)
+
     def anomaly_score(self, input_data):
         """Returns the anomaly score given by the iforest
             To produce an anomaly score, we evaluate each tree in the iforest
@@ -280,7 +289,6 @@ class Anomaly(ModelFields):
             return 1
         # Checks and cleans input_data leaving the fields used in the model
         norm_input_data = self.filter_input_data(input_data)
-
         # Strips affixes for numeric values and casts to the final field type
         cast(norm_input_data, self.fields)
 
@@ -299,7 +307,8 @@ class Anomaly(ModelFields):
             depth_sum += tree_depth
 
         observed_mean_depth = float(depth_sum) / len(self.iforest)
-        return math.pow(2, - observed_mean_depth / self.norm)
+        return round(math.pow(2, - observed_mean_depth / self.norm),
+                     DECIMALS)
 
     def anomalies_filter(self, include=True):
         """Returns the LISP expression needed to filter the subset of
@@ -359,21 +368,13 @@ class Anomaly(ModelFields):
         """
         if outputs is None:
             outputs = {}
-        if outputs.get(OUT_NEW_HEADERS):
-            new_headers = outputs.get(OUT_NEW_HEADERS, DFT_OUTPUTS)
-        else:
-            new_headers = DFT_OUTPUTS
-
-        dataframe = False
-        if PANDAS_READY and isinstance(input_data_list, DataFrame):
-            dataframe = True
-            inner_data_list = input_data_list.to_dict('records')
-        else:
-            inner_data_list = input_data_list[:]
+        new_headers = outputs.get(OUT_NEW_HEADERS, DFT_OUTPUTS)
+        data_format = get_data_format(input_data_list)
+        inner_data_list = get_formatted_data(input_data_list, INTERNAL)
         for input_data in inner_data_list:
             prediction = {"score": self.anomaly_score(input_data, **kwargs)}
             for index, key in enumerate(DFT_OUTPUTS):
                 input_data[new_headers[index]] = prediction[key]
-        if PANDAS_READY and dataframe:
-            return DataFrame.from_dict(inner_data_list)
+        if data_format != INTERNAL:
+            return format_data(inner_data_list, out_format=data_format)
         return inner_data_list
