@@ -451,7 +451,8 @@ def exception_on_error(resource, logger=None):
 
 def check_resource(resource, get_method=None, query_string='', wait_time=1,
                    retries=None, raise_on_error=False,
-                   max_elapsed_estimate=float('inf'), api=None, debug=False):
+                   max_elapsed_estimate=float('inf'), api=None, debug=False,
+                   progress_cb=None):
     """Waits until a resource is finished.
 
        Given a resource and its corresponding get_method (if absent, the
@@ -463,6 +464,7 @@ def check_resource(resource, get_method=None, query_string='', wait_time=1,
        parameter.
 
     """
+
     resource_id = get_resource_id(resource)
     # ephemeral predictions
     if isinstance(resource, dict) and resource.get("resource") is None:
@@ -481,7 +483,9 @@ def check_resource(resource, get_method=None, query_string='', wait_time=1,
     elif get_method is None:
         raise ValueError("You must supply either the get_method or the api"
                          " connection info to retrieve the resource")
-    if not isinstance(resource, dict) and not http_ok(resource):
+
+    if not isinstance(resource, dict) or not http_ok(resource) or \
+            resource.get("object") is None:
         resource = resource_id
 
     if isinstance(resource, str):
@@ -497,6 +501,7 @@ def check_resource(resource, get_method=None, query_string='', wait_time=1,
     counter = 0
     elapsed = 0
     while retries is None or counter < retries:
+
         counter += 1
         status = get_status(resource)
         code = status['code']
@@ -516,7 +521,24 @@ def check_resource(resource, get_method=None, query_string='', wait_time=1,
             if raise_on_error:
                 exception_on_error(resource)
             return resource
-        _wait_time = get_exponential_wait(wait_time, counter)
+        # resource is ok
+        progress = 0
+        #pylint: disable=locally-disabled, bare-except
+        if status is not None:
+            progress = status.get("progress", 0)
+            if debug:
+                print("Progress: %s" % progress)
+            try:
+                if progress_cb is not None:
+                    progress_cb(progress, resource)
+            except:
+                print("WARNING: Progress callback raised exception. Please,"
+                      "double check your function.")
+            progress = progress if progress > 0.8 \
+                else 0 # dumping when almost finished
+        progress_dumping = (1 - progress)
+        _wait_time = get_exponential_wait(wait_time,
+            max(int(counter * progress_dumping), 1))
         _max_wait = max_elapsed_estimate - _wait_time
         _wait_time = min(_max_wait, _wait_time)
         if _wait_time <= 0:
@@ -641,7 +663,8 @@ class ResourceHandlerMixin(metaclass=abc.ABCMeta):
     #pylint: disable=locally-disabled,invalid-name
     def ok(self, resource, query_string='', wait_time=1,
            max_requests=None, raise_on_error=False, retries=None,
-           error_retries=None, max_elapsed_estimate=float('inf'), debug=False):
+           error_retries=None, max_elapsed_estimate=float('inf'), debug=False,
+           progress_cb=None):
         """Waits until the resource is finished or faulty, updates it and
            returns True when a finished resource is correctly retrieved
            and False if the retrieval fails or the resource is faulty.
@@ -658,6 +681,7 @@ class ResourceHandlerMixin(metaclass=abc.ABCMeta):
                                     This is not a hard limit for the method
                                     to end, but an estimation of time to wait.
              debug: (boolean) Whether to print traces for every get call
+             progress_cb: (function) Callback function to log progress
 
         """
         def maybe_retrying(resource, error_retries, new_resource=None):
@@ -687,8 +711,8 @@ class ResourceHandlerMixin(metaclass=abc.ABCMeta):
             max_elapsed_estimate=max_elapsed_estimate,
             raise_on_error=False, # we don't raise on error to update always
             api=self,
-            debug=debug)
-
+            debug=debug,
+            progress_cb=progress_cb)
 
         if http_ok(new_resource):
             resource.update(new_resource)
