@@ -440,12 +440,13 @@ class SourceHandlerMixin(ResourceHandlerMixin):
             source = self.get_source(source_id)
             if source.get("object", {}).get("closed"):
                 source = self.clone_source(source_id)
+        self.ok(source)
         # corresponding source IDs
         try:
             sources = source["object"]["sources"]
         except KeyError:
             raise ValueError("Failed to find the list of sources in the "
-                             "created composite.")
+                             "created composite: %s." % source["resource"])
         try:
             with ZipFile(images_file) as zip_handler:
                 file_list = zip_handler.namelist()
