@@ -45,22 +45,18 @@ import re
 import csv
 import codecs
 
-try:
-    from pandas import DataFrame
-    PANDAS_READY = True
-except ImportError:
-    PANDAS_READY = False
 
 from bigml.api import FINISHED
 from bigml.api import get_status, get_api_connection, get_cluster_id
-from bigml.util import cast, utf8, NUMERIC, use_cache, load, dump, dumps
+from bigml.util import cast, utf8, NUMERIC, use_cache, load, dump, dumps, \
+    get_data_format, get_formatted_data, format_data, get_data_transformations
 from bigml.centroid import Centroid
 from bigml.basemodel import get_resource_dict
 from bigml.generators.model import print_distribution
 from bigml.predicate import TM_TOKENS, TM_FULL_TERM
 from bigml.modelfields import ModelFields
 from bigml.io import UnicodeWriter
-from bigml.constants import OUT_NEW_FIELDS, OUT_NEW_HEADERS
+from bigml.constants import OUT_NEW_FIELDS, OUT_NEW_HEADERS, INTERNAL
 
 
 LOGGER = logging.getLogger('BigML')
@@ -164,7 +160,9 @@ class Cluster(ModelFields):
             return
 
         self.resource_id = None
-        self.dataset_id = None
+        self.name = None
+        self.description = None
+        self.parent_id = None
         self.cluster_global = None
         self.total_ss = None
         self.within_ss = None
@@ -190,7 +188,13 @@ class Cluster(ModelFields):
 
         if 'object' in cluster and isinstance(cluster['object'], dict):
             cluster = cluster['object']
-            self.dataset_id = cluster.get('dataset')
+        try:
+            self.parent_id = cluster.get('dataset')
+            self.name = cluster.get("name")
+            self.description = cluster.get("description")
+        except AttributeError:
+            raise ValueError("Failed to find the expected "
+                             "JSON structure. Check your arguments.")
 
         if 'clusters' in cluster and isinstance(cluster['clusters'], dict):
             status = get_status(cluster)
@@ -664,30 +668,29 @@ class Cluster(ModelFields):
         """
         if outputs is None:
             outputs = {}
-        if outputs.get(OUT_NEW_FIELDS) is None:
-            new_fields = DFT_OUTPUTS
-        if outputs.get(OUT_NEW_HEADERS):
-            new_headers = outputs.get(OUT_NEW_HEADERS, new_fields)
-            if len(new_fields) > len(new_headers):
-                new_headers.expand(new_fields[len(new_headers):])
-            else:
-                new_headers = new_headers[0: len(new_fields)]
+        new_fields = outputs.get(OUT_NEW_FIELDS, DFT_OUTPUTS)
+        new_headers = outputs.get(OUT_NEW_HEADERS, new_fields)
+        if len(new_fields) > len(new_headers):
+            new_headers.expand(new_fields[len(new_headers):])
         else:
-            new_headers = new_fields
-        dataframe = False
-        if PANDAS_READY and isinstance(input_data_list, DataFrame):
-            dataframe = True
-            inner_data_list = input_data_list.to_dict('records')
-        else:
-            inner_data_list = input_data_list[:]
+            new_headers = new_headers[0: len(new_fields)]
+        data_format = get_data_format(input_data_list)
+        inner_data_list = get_formatted_data(input_data_list, INTERNAL)
         for input_data in inner_data_list:
             prediction = self.centroid(input_data, **kwargs)
             for index, key in enumerate(new_fields):
                 input_data[new_headers[index]] = prediction[key]
-        if PANDAS_READY and dataframe:
-            return DataFrame.from_dict(inner_data_list)
+        if data_format != INTERNAL:
+            return format_data(inner_data_list, out_format=data_format)
         return inner_data_list
 
+    def data_transformations(self):
+        """Returns the pipeline transformations previous to the modeling
+        step as a pipeline, so that they can be used in local predictions.
+        Avoiding to set it in a Mixin to maintain the current dump function.
+        """
+        return get_data_transformations(self.resource_id, self.parent_id)
+
     def dump(self, output=None, cache_set=None):
         """Uses msgpack to serialize the resource object
         If cache_set is filled with a cache set method, the method is called
