@@ -59,8 +59,9 @@ from bigml.basemodel import BaseModel, print_importance, check_local_but_fields
 from bigml.modelfields import ModelFields, NUMERIC
 from bigml.multivotelist import MultiVoteList
 from bigml.tree_utils import add_distribution
-from bigml.util import cast, use_cache, load, dump, dumps
-
+from bigml.util import cast, use_cache, load, dump, dumps, \
+    get_data_transformations
+from bigml.constants import DECIMALS
 
 BOOSTING = 1
 LOGGER = logging.getLogger('BigML')
@@ -139,7 +140,9 @@ class Ensemble(ModelFields):
             return
 
         self.resource_id = None
-        self.dataset_id = None
+        self.name = None
+        self.description = None
+        self.parent_id = None
         self.objective_id = None
         self.distributions = None
         self.distribution = None
@@ -212,7 +215,9 @@ class Ensemble(ModelFields):
                 ensemble = retrieve_resource(self.api, self.resource_id,
                                              no_check_fields=True)
 
-            self.dataset_id = ensemble.get('object', {}).get('dataset')
+            self.parent_id = ensemble.get('object', {}).get('dataset')
+            self.name = ensemble.get('object', {}).get('name')
+            self.description = ensemble.get('object', {}).get('description')
             if ensemble['object'].get('type') == BOOSTING:
                 self.boosting = ensemble['object'].get('boosting')
             self.distributions = ensemble['object'].get('distributions', [])
@@ -854,7 +859,7 @@ class Ensemble(ModelFields):
                 unused_fields = unused_fields.intersection( \
                     set(prediction.get("unused_fields", [])))
             if not isinstance(result, dict):
-                result = {"prediction": result}
+                result = {"prediction": round(result, DECIMALS)}
             result['unused_fields'] = list(unused_fields)
 
         return result
@@ -1009,12 +1014,19 @@ class Ensemble(ModelFields):
         gc.collect()
         return fields, objective_id
 
+    def data_transformations(self):
+        """Returns the pipeline transformations previous to the modeling
+        step as a pipeline, so that they can be used in local predictions.
+        Avoiding to set it in a Mixin to maintain the current dump function.
+        """
+        return get_data_transformations(self.resource_id, self.parent_id)
+
     def dump(self, output=None, cache_set=None):
         """Uses msgpack to serialize the resource object
         If cache_set is filled with a cache set method, the method is called
 
         """
-        self_vars = vars(self)
+        self_vars = vars(self).copy()
         del self_vars["api"]
         if "multi_model" in self_vars:
             for model in self_vars["multi_model"].models:
@@ -1026,7 +1038,7 @@ class Ensemble(ModelFields):
         """Uses msgpack to serialize the resource object to a string
 
         """
-        self_vars = vars(self)
+        self_vars = vars(self).copy()
         del self_vars["api"]
         if "multi_model" in self_vars:
             del self_vars["multi_model"]
