@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2020-2021 BigML
+# Copyright 2020-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -98,8 +98,12 @@ def list_fields(model, out=sys.stdout):
         model.fields[model.objective_id]['optype'])))
     out.flush()
 
+    if hasattr(model, "model_fields"):
+        fields = model.model_fields
+    else:
+        fields = model.fields
     for field in [(val['name'], val['optype']) for key, val in
-                  sort_fields(model.fields)
+                  sort_fields(fields)
                   if key != model.objective_id]:
         out.write(utf8('[%-32s : %s]\n' % (field[0], field[1])))
         out.flush()
@@ -556,13 +560,13 @@ def term_analysis_body(fields, term_analysis_predicates,
                     terms = [term]
                     terms.extend(all_forms.get(term, []))
                     term_forms[field['slug']][term] = terms
-        for field in term_forms:
+        for field, field_term_forms in term_forms.items():
             body += """
         \"%s\": {""" % field
-            terms = sorted(term_forms[field].keys())
+            terms = sorted(field_term_forms.keys())
             for term in terms:
                 body += """
-            \"%s\": %s,""" % (term, term_forms[field][term])
+            \"%s\": %s,""" % (term, field_term_forms[term])
             body += """
         },"""
         body += """
@@ -847,6 +851,7 @@ def get_prediction_distribution(model, groups=None):
     return sorted(predictions, key=lambda x: x[0])
 
 
+#pylint: disable=locally-disabled,redefined-builtin
 def summarize(model, out=sys.stdout, format=BRIEF):
     """Prints summary grouping distribution as class header and details
 
