@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
+#pylint: disable=invalid-name,missing-function-docstring
 #
-# Copyright 2017-2021 BigML
+# Copyright 2017-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -22,6 +23,7 @@ numpy.
 
 import numpy as np
 
+#pylint: disable=locally-disabled,no-name-in-module
 from scipy.special import expit
 
 from bigml.laminar.constants import LARGE_EXP, MATRIX_PARAMS, \
@@ -156,7 +158,13 @@ def sum_and_normalize(youts, is_regression):
 
 def propagate(x_in, layers):
     last_X = identities = to_numpy_array(x_in)
-    for layer in layers:
+
+    if any(layer["residuals"] for layer in layers):
+        first_identities = not any(layer["residuals"] for layer in layers[:2])
+    else:
+        first_identities = False
+
+    for i, layer in enumerate(layers):
         w = layer['weights']
         m = layer['mean']
         s = layer['stdev']
@@ -178,4 +186,7 @@ def propagate(x_in, layers):
         else:
             last_X = ACTIVATORS[afn](next_in)
 
+            if first_identities and i == 0:
+                identities = last_X
+
     return last_X
