@@ -49,7 +49,7 @@ from bigml.api import FINISHED
 from bigml.api import get_status, get_api_connection, \
     get_logistic_regression_id
 from bigml.util import cast, check_no_missing_numerics, use_cache, load, \
-    PRECISION, NUMERIC
+    get_data_transformations, PRECISION, NUMERIC
 from bigml.basemodel import get_resource_dict, extract_objective
 from bigml.model import parse_operating_point, sort_categories
 from bigml.modelfields import ModelFields
@@ -119,7 +119,9 @@ class LogisticRegression(ModelFields):
             return
 
         self.resource_id = None
-        self.dataset_id = None
+        self.name = None
+        self.description = None
+        self.parent_id = None
         self.class_names = None
         self.input_fields = []
         self.term_forms = {}
@@ -151,7 +153,9 @@ class LogisticRegression(ModelFields):
         if 'object' in logistic_regression and \
             isinstance(logistic_regression['object'], dict):
             logistic_regression = logistic_regression['object']
-            self.dataset_id = logistic_regression.get('dataset')
+            self.parent_id = logistic_regression.get('dataset')
+            self.name = logistic_regression.get("name")
+            self.description = logistic_regression.get("description")
         try:
             self.input_fields = logistic_regression.get("input_fields", [])
             self.default_numeric_value = logistic_regression.get(
@@ -604,3 +608,10 @@ class LogisticRegression(ModelFields):
                 else:
                     self.field_codings[field_id] = {\
                         element["coding"]: element['coefficients']}
+
+    def data_transformations(self):
+        """Returns the pipeline transformations previous to the modeling
+        step as a pipeline, so that they can be used in local predictions.
+        Avoiding to set it in a Mixin to maintain the current dump function.
+        """
+        return get_data_transformations(self.resource_id, self.parent_id)
