@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012-2021 BigML
+# Copyright 2012-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -19,7 +19,7 @@
 This module defines a Multiple Model to make predictions locally using multiple
 local models.
 
-This module cannot only save you a few credits, but also enormously
+This module can help you enormously to
 reduce the latency for each prediction and let you use your models
 offline.
 
@@ -103,26 +103,30 @@ class MultiModel():
     """
 
     def __init__(self, models, api=None, fields=None, class_names=None,
-                 cache_get=None):
+                 cache_get=None, operation_settings=None):
 
         self.models = []
         self.class_names = class_names
 
         if isinstance(models, list):
-            if all([isinstance(model, Model) for model in models]):
+            if all(isinstance(model, Model) for model in models):
                 self.models = models
             else:
                 for model in models:
                     # some models have no root info and should not be added
                     try:
-                        self.models.append(Model(model, api=api, fields=fields,
-                                                 cache_get=cache_get))
+                        self.models.append(Model(
+                            model, api=api, fields=fields,
+                            cache_get=cache_get,
+                            operation_settings=operation_settings))
                     except NoRootDecisionTree:
                         pass
         else:
             try:
-                self.models.append(Model(models, api=api, fields=fields,
-                                         cache_get=cache_get))
+                self.models.append(Model(
+                    models, api=api, fields=fields,
+                    cache_get=cache_get,
+                    operation_settings=operation_settings))
             except NoRootDecisionTree:
                 pass
 
@@ -168,8 +172,7 @@ class MultiModel():
             made by each of the models.
         """
         votes = MultiVote([])
-        for order in range(0, len(self.models)):
-            model = self.models[order]
+        for model in self.models:
             prediction_info = model.predict( \
                 input_data, missing_strategy=missing_strategy, full=True)
 
@@ -185,6 +188,7 @@ class MultiModel():
 
         return votes
 
+    #pylint: disable=locally-disabled,protected-access
     def _generate_votes(self, input_data, missing_strategy=LAST_PREDICTION,
                         unused_fields=None):
         """ Generates a MultiVote object that contains the predictions
@@ -194,8 +198,7 @@ class MultiModel():
             to the correct type will be applied.
         """
         votes = MultiVote([])
-        for order in range(0, len(self.models)):
-            model = self.models[order]
+        for model in self.models:
             prediction_info = model._predict( \
                 input_data,
                 missing_strategy=missing_strategy, unused_fields=unused_fields)
@@ -216,6 +219,10 @@ class MultiModel():
                                     input_data,
                                     missing_strategy=LAST_PREDICTION,
                                     method=PROBABILITY_CODE):
+        """Generates a MultiVoteList object to contain the predictions
+        of a list of models as the list of classes and their predicted
+        probabilities or confidence.
+        """
         votes = []
         for model in self.models:
             model.class_names = self.class_names
@@ -273,9 +280,8 @@ class MultiModel():
                                                         output_file_path)
                 if reuse:
                     try:
-                        predictions_file = open(output_file)
-                        predictions_file.close()
-                        continue
+                        with open(output_file):
+                            continue
                     except IOError:
                         pass
                 try:
@@ -310,6 +316,7 @@ class MultiModel():
                 out.close_writer()
         if not to_file:
             return votes
+        return output_file_path
 
     def batch_votes(self, predictions_file_path, data_locale=None):
         """Adds the votes for predictions generated by the models.
