@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014-2021 BigML
+# Copyright 2014-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -52,6 +52,6 @@ class Predicates():
 
         """
 
-        return all([predicate.apply(input_data, fields) for
-                    predicate in self.predicates
-                    if isinstance(predicate, Predicate)])
+        return all(predicate.apply(input_data, fields) for
+                   predicate in self.predicates
+                   if isinstance(predicate, Predicate))
