@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014-2021 BigML
+# Copyright 2014-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -19,7 +19,7 @@ import json
 import os
 import io
 from datetime import datetime
-from .world import world, res_filename, logged_wait
+from .world import world, res_filename
 from nose.tools import eq_, assert_less
 
 from bigml.api import BigML
@@ -29,9 +29,8 @@ from bigml.api import FINISHED
 from bigml.api import FAULTY
 from bigml.api import get_status
 from bigml.association import Association
-from bigml.util import get_exponential_wait
 
-from .read_association_steps import i_get_the_association
+from .read_resource_steps import wait_until_status_code_is
 
 
 #@step(r'the association name is "(.*)"')
@@ -40,14 +39,15 @@ def i_check_association_name(step, name):
     eq_(name, association_name)
 
 #@step(r'I create an association from a dataset$')
-def i_create_an_association_from_dataset(step):
-    dataset = world.dataset.get('resource')
-    resource = world.api.create_association(dataset, {'name': 'new association'})
-    world.status = resource['code']
-    eq_(world.status, HTTP_CREATED)
-    world.location = resource['location']
-    world.association = resource['object']
-    world.associations.append(resource['resource'])
+def i_create_an_association_from_dataset(step, shared=None):
+    if shared is None or world.shared.get("association", {}).get("shared") is None:
+        dataset = world.dataset.get('resource')
+        resource = world.api.create_association(dataset, {'name': 'new association'})
+        world.status = resource['code']
+        eq_(world.status, HTTP_CREATED)
+        world.location = resource['location']
+        world.association = resource['object']
+        world.associations.append(resource['resource'])
 
 
 #@step(r'I create an association from a dataset with params (.*)$')
@@ -90,25 +90,21 @@ def i_update_association_name(step, name):
 
 #@step(r'I wait until the association status code is either (\d) or (-\d) less than (\d+)')
 def wait_until_association_status_code_is(step, code1, code2, secs):
-    start = datetime.utcnow()
-    delta = int(secs) * world.delta
-    association_id = world.association['resource']
-    i_get_the_association(step, association_id)
-    status = get_status(world.association)
-    count = 0
-    while (status['code'] != int(code1) and
-           status['code'] != int(code2)):
-        count += 1
-        logged_wait(start, delta, count, "association")
-        i_get_the_association(step, association_id)
-        status = get_status(world.association)
-    eq_(status['code'], int(code1))
+    world.association = wait_until_status_code_is(
+        code1, code2, secs, world.association)
 
 
 #@step(r'I wait until the association is ready less than (\d+)')
-def the_association_is_finished_in_less_than(step, secs):
-    wait_until_association_status_code_is(step, FINISHED, FAULTY, secs)
-
+def the_association_is_finished_in_less_than(step, secs, shared=None):
+    if shared is None or world.shared.get("association", {}).get(shared) is None:
+        wait_until_association_status_code_is(step, FINISHED, FAULTY, secs)
+        if shared is not None:
+            if "association" not in world.shared:
+                world.shared["association"] = {}
+            world.shared["association"][shared] = world.association
+    else:
+        world.association = world.shared["association"][shared]
+        print("Reusing %s" % world.association["resource"])
 
 #@step(r'I create a local association')
 def i_create_a_local_association(step):
@@ -143,3 +139,18 @@ def i_create_local_association_from_file(step, export_file):
 #@step(r'the association ID and the local association ID match')
 def check_association_id_local_id(step):
     eq_(world.local_association.resource_id, world.association["resource"])
+
+
+#@step(r'I clone association')
+def clone_association(step, association):
+    resource = world.api.clone_association(association,
+                                           {'project': world.project_id})
+    # update status
+    world.status = resource['code']
+    world.location = resource['location']
+    world.association = resource['object']
+    # save reference
+    world.associations.append(resource['resource'])
+
+def the_cloned_association_is(step, association):
+    eq_(world.association["origin"], association)
