@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2015-2021 BigML
+# Copyright 2015-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -18,7 +18,7 @@ import time
 import json
 import os
 from datetime import datetime
-from .world import world, logged_wait
+from .world import world
 from nose.tools import eq_, assert_less
 
 from bigml.api import HTTP_CREATED
@@ -27,7 +27,7 @@ from bigml.api import FINISHED
 from bigml.api import FAULTY
 from bigml.api import get_status
 
-from .read_correlation_steps import i_get_the_correlation
+from .read_resource_steps import wait_until_status_code_is
 
 
 #@step(r'the correlation name is "(.*)"')
@@ -58,20 +58,8 @@ def i_update_correlation_name(step, name):
 
 #@step(r'I wait until the correlation status code is either (\d) or (-\d) less than (\d+)')
 def wait_until_correlation_status_code_is(step, code1, code2, secs):
-    start = datetime.utcnow()
-    delta = int(secs) * world.delta
-    correlation_id = world.correlation['resource']
-    i_get_the_correlation(step, correlation_id)
-    status = get_status(world.correlation)
-    count = 0
-    while (status['code'] != int(code1) and
-           status['code'] != int(code2)):
-        count += 1
-        logged_wait(start, delta, count, "correlation")
-        assert_less((datetime.utcnow() - start).seconds, delta)
-        i_get_the_correlation(step, correlation_id)
-        status = get_status(world.correlation)
-    eq_(status['code'], int(code1))
+    world.correlation = wait_until_status_code_is(
+        code1, code2, secs, world.correlation)
 
 
 #@step(r'I wait until the correlation is ready less than (\d+)')
