@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012-2021 BigML
+# Copyright 2012-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -17,7 +17,7 @@
 import time
 import json
 from datetime import datetime
-from .world import world, res_filename, logged_wait
+from .world import world, res_filename
 from nose.tools import eq_, assert_less
 from bigml.api import HTTP_CREATED
 from bigml.api import HTTP_OK
@@ -26,12 +26,12 @@ from bigml.api import FINISHED
 from bigml.api import FAULTY
 from bigml.api import get_status
 
-from . import read_dataset_steps as read
+from .read_resource_steps import wait_until_status_code_is
 
 
 #@step(r'I create a dataset$')
 def i_create_a_dataset(step, shared=None):
-    if shared is None or step.shared.get(shared, {}).get("dataset") is None:
+    if shared is None or world.shared.get("dataset", {}).get(shared) is None:
         resource = world.api.create_dataset(world.source['resource'])
         world.status = resource['code']
         eq_(world.status, HTTP_CREATED)
@@ -63,27 +63,21 @@ def i_create_a_dataset_with(step, data="{}"):
 
 #@step(r'I wait until the dataset status code is either (\d) or (\d) less than (\d+)')
 def wait_until_dataset_status_code_is(step, code1, code2, secs):
-    start = datetime.utcnow()
-    delta = int(secs) * world.delta
-    read.i_get_the_dataset(step, world.dataset['resource'])
-    status = get_status(world.dataset)
-    count = 0
-    while (status['code'] != int(code1) and
-           status['code'] != int(code2)):
-        count += 1
-        logged_wait(start, delta, count, "dataset")
-        read.i_get_the_dataset(step, world.dataset['resource'])
-        status = get_status(world.dataset)
-    eq_(status['code'], int(code1))
+    world.dataset = wait_until_status_code_is(
+        code1, code2, secs, world.dataset)
+
 
 #@step(r'I wait until the dataset is ready less than (\d+)')
 def the_dataset_is_finished_in_less_than(step, secs, shared=None):
-    if shared is None or step.shared.get(shared, {}).get("dataset") is None:
+    if shared is None or world.shared.get("dataset", {}).get(shared) is None:
         wait_until_dataset_status_code_is(step, FINISHED, FAULTY, secs)
         if shared is not None:
-            step.shared[shared]["dataset"]= world.dataset
+            if "dataset" not in world.shared:
+                world.shared["dataset"] = {}
+            world.shared["dataset"][shared]= world.dataset
     else:
-        world.dataset = step.shared[shared]["dataset"]
+        world.dataset = world.shared["dataset"][shared]
+        print("Reusing %s" % world.dataset["resource"])
 
 #@step(r'I make the dataset public')
 def make_the_dataset_public(step):
@@ -194,3 +188,16 @@ def i_update_dataset_with(step, data="{}"):
                                         json.loads(data))
     world.status = resource['code']
     eq_(world.status, HTTP_ACCEPTED)
+
+#@step(r'I clone dataset')
+def clone_dataset(step, dataset):
+    resource = world.api.clone_dataset(dataset, {'project': world.project_id})
+    # update status
+    world.status = resource['code']
+    world.location = resource['location']
+    world.dataset = resource['object']
+    # save reference
+    world.datasets.append(resource['resource'])
+
+def the_cloned_dataset_is(step, dataset):
+    eq_(world.dataset["origin"], dataset)
