@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 #
-# Copyright 2012-2021 BigML
+# Copyright 2012-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -20,7 +20,7 @@ import json
 import os
 from nose.tools import eq_, assert_less
 from datetime import datetime
-from .world import world, res_filename, logged_wait
+from .world import world, res_filename
 
 from bigml.api import HTTP_OK
 from bigml.api import HTTP_CREATED
@@ -35,13 +35,15 @@ from bigml.linear import LinearRegression
 from bigml.deepnet import Deepnet
 from bigml.fusion import Fusion
 
-from . import read_model_steps as read
+
+from .read_resource_steps import wait_until_status_code_is
+
 
 NO_MISSING_SPLITS = {'missing_splits': False}
 
 #@step(r'I create a model$')
 def i_create_a_model(step, shared=None):
-    if shared is None or step.shared.get(shared, {}).get("model") is None:
+    if shared is None or world.shared.get("model", {}).get(shared) is None:
         dataset = world.dataset.get('resource')
         resource = world.api.create_model(dataset, args=NO_MISSING_SPLITS)
         world.status = resource['code']
@@ -86,28 +88,20 @@ def i_create_a_model_from_dataset_list(step):
 
 #@step(r'I wait until the model status code is either (\d) or (-\d) less than (\d+)')
 def wait_until_model_status_code_is(step, code1, code2, secs):
-    start = datetime.utcnow()
-    delta = int(secs) * world.delta
-    read.i_get_the_model(step, world.model['resource'])
-    status = get_status(world.model)
-    count = 0
-    while (status['code'] != int(code1) and
-           status['code'] != int(code2)):
-        count += 1
-        logged_wait(start, delta, count, "model")
-        assert_less((datetime.utcnow() - start).seconds, delta)
-        read.i_get_the_model(step, world.model['resource'])
-        status = get_status(world.model)
-    eq_(status['code'], int(code1))
+    wait_until_status_code_is(code1, code2, secs, world.model)
 
 #@step(r'I wait until the model is ready less than (\d+)')
 def the_model_is_finished_in_less_than(step, secs, shared=None):
-    if shared is None or step.shared.get(shared, {}).get("model") is None:
+    if shared is None or world.shared.get("model", {}).get(shared) is None:
         wait_until_model_status_code_is(step, FINISHED, FAULTY, secs)
         if shared is not None:
-            step.shared[shared]["model"] = world.model
+            if "model" not in world.shared:
+                world.shared["model"] = {}
+            world.shared["model"][shared] = world.model
+        print("New %s" % world.model["resource"])
     else:
-        world.model = step.shared[shared]["model"]
+        world.model = world.shared["model"][shared]
+        print("Reusing %s" % world.model["resource"])
 
 
 #@step(r'I create a model with "(.*)"')
@@ -198,14 +192,15 @@ def is_associated_to_centroid_id(step, centroid_id):
         world.model['resource'])
 
 #@step(r'I create a logistic regression model$')
-def i_create_a_logistic_model(step):
-    dataset = world.dataset.get('resource')
-    resource = world.api.create_logistic_regression(dataset)
-    world.status = resource['code']
-    eq_(world.status, HTTP_CREATED)
-    world.location = resource['location']
-    world.logistic_regression = resource['object']
-    world.logistic_regressions.append(resource['resource'])
+def i_create_a_logistic_model(step, shared=None):
+    if shared is None or world.shared.get("logistic", {}).get(shared) is None:
+        dataset = world.dataset.get('resource')
+        resource = world.api.create_logistic_regression(dataset)
+        world.status = resource['code']
+        eq_(world.status, HTTP_CREATED)
+        world.location = resource['location']
+        world.logistic_regression = resource['object']
+        world.logistic_regressions.append(resource['resource'])
 
 
 #@step(r'I create a logistic regression model with objective "(.*?)" and parms "(.*)"$')
@@ -227,45 +222,55 @@ def i_create_a_logistic_model_with_objective_and_parms(step, objective=None, par
 
 #@step(r'I wait until the logistic regression model status code is either (\d) or (-\d) less than (\d+)')
 def wait_until_logistic_model_status_code_is(step, code1, code2, secs):
-    start = datetime.utcnow()
-    delta = int(secs) * world.delta
-    read.i_get_the_logistic_model(step, world.logistic_regression['resource'])
-    status = get_status(world.logistic_regression)
-    count = 0
-    while (status['code'] != int(code1) and
-           status['code'] != int(code2)):
-        count += 1
-        logged_wait(start, delta, count, "logisticregression")
-        read.i_get_the_logistic_model(step, world.logistic_regression['resource'])
-        status = get_status(world.logistic_regression)
-    eq_(status['code'], int(code1))
+    world.logistic_regression = wait_until_status_code_is(
+        code1, code2, secs, world.logistic_regression)
 
 #@step(r'I wait until the logistic regression model is ready less than (\d+)')
-def the_logistic_model_is_finished_in_less_than(step, secs):
-    wait_until_logistic_model_status_code_is(step, FINISHED, FAULTY, secs)
+def the_logistic_model_is_finished_in_less_than(step, secs, shared=None):
+    if shared is None or world.shared.get("logistic", {}).get(shared) is None:
+        wait_until_logistic_model_status_code_is(step, FINISHED, FAULTY, secs)
+        if shared is not None:
+            if "logistic" not in world.shared:
+                world.shared["logistic"] = {}
+            world.shared["logistic"][shared] = world.logistic_regression
+    else:
+        world.logistic_regression = world.shared["logistic"][shared]
+        print("Reusing %s" % world.logistic_regression["resource"])
 
 #@step(r'I create a deepnet model$')
-def i_create_a_deepnet(step):
+def i_create_a_deepnet(step, shared=None):
+    if shared is None or world.shared.get("deepnet", {}).get(shared) is None:
+        dataset = world.dataset.get('resource')
+        resource = world.api.create_deepnet(dataset)
+        world.status = resource['code']
+        eq_(world.status, HTTP_CREATED)
+        world.location = resource['location']
+        world.deepnet = resource['object']
+        world.deepnets.append(resource['resource'])
+
+#@step(r'I create a quick deepnet$')
+def i_create_a_quick_deepnet(step):
     dataset = world.dataset.get('resource')
-    resource = world.api.create_deepnet(dataset)
+    resource = world.api.create_deepnet(dataset, {"max_training_time": 100})
     world.status = resource['code']
     eq_(world.status, HTTP_CREATED)
     world.location = resource['location']
     world.deepnet = resource['object']
     world.deepnets.append(resource['resource'])
 
-
 #@step(r'I create a non-suggested deepnet model$')
-def i_create_a_no_suggest_deepnet(step):
-    dataset = world.dataset.get('resource')
-    resource = world.api.create_deepnet(dataset, {"suggest_structure": False,
-                                                  "max_iterations": 100,
-                                                  "deepnet_seed": "bigml"})
-    world.status = resource['code']
-    eq_(world.status, HTTP_CREATED)
-    world.location = resource['location']
-    world.deepnet = resource['object']
-    world.deepnets.append(resource['resource'])
+def i_create_a_no_suggest_deepnet(step, shared=None):
+    if shared is None or \
+            world.shared.get("deepnet", {}).get(shared) is None:
+        dataset = world.dataset.get('resource')
+        resource = world.api.create_deepnet(dataset, {"suggest_structure": False,
+                                                      "max_iterations": 100,
+                                                      "deepnet_seed": "bigml"})
+        world.status = resource['code']
+        eq_(world.status, HTTP_CREATED)
+        world.location = resource['location']
+        world.deepnet = resource['object']
+        world.deepnets.append(resource['resource'])
 
 #@step(r'I create a deepnet model with objective "(.*?)" and parms "(.*)"$')
 def i_create_a_deepnet_with_objective_and_params(step, objective=None, parms=None):
@@ -285,21 +290,20 @@ def i_create_a_deepnet_with_objective_and_params(step, objective=None, parms=Non
 
 #@step(r'I wait until the deepnet model status code is either (\d) or (-\d) less than (\d+)')
 def wait_until_deepnet_model_status_code_is(step, code1, code2, secs):
-    start = datetime.utcnow()
-    delta = int(secs) * world.delta
-    status = get_status(world.deepnet)
-    count = 0
-    while (status['code'] != int(code1) and
-           status['code'] != int(code2)):
-        count += 1
-        logged_wait(start, delta, count, "deepnet")
-        read.i_get_the_deepnet_model(step, world.deepnet['resource'])
-        status = get_status(world.deepnet)
-    eq_(status['code'], int(code1))
+   world.deepnet = wait_until_status_code_is(code1, code2, secs, world.deepnet)
 
 #@step(r'I wait until the deepnet model is ready less than (\d+)')
-def the_deepnet_is_finished_in_less_than(step, secs):
-    wait_until_deepnet_model_status_code_is(step, FINISHED, FAULTY, secs)
+def the_deepnet_is_finished_in_less_than(step, secs, shared=None):
+    if shared is None or world.shared.get("deepnet", {}).get(shared) is None:
+        wait_until_deepnet_model_status_code_is(step, FINISHED, FAULTY, secs)
+        if shared is not None:
+            if "deepnete" not in world.shared:
+                world.shared["deepnet"] = {}
+            world.shared["deepnet"][shared] = world.deepnet
+    else:
+        world.deepnet = world.shared["deepnet"][shared]
+        print("Reusing %s" % world.deepnet["resource"])
+
 
 #@step(r'I export the "(.*)" model to file "(.*)"$')
 def i_export_model(step, pmml, filename):
@@ -347,18 +351,7 @@ def i_create_an_optiml_with_objective_and_params(step, objective=None, parms=Non
 
 #@step(r'I wait until the optiml status code is either (\d) or (-\d) less than (\d+)')
 def wait_until_optiml_status_code_is(step, code1, code2, secs):
-    start = datetime.utcnow()
-    delta = int(secs) * world.delta
-    read.i_get_the_optiml(step, world.optiml['resource'])
-    status = get_status(world.optiml)
-    count = 0
-    while (status['code'] != int(code1) and
-           status['code'] != int(code2)):
-        count += 1
-        logged_wait(start, delta, count, "optiml")
-        read.i_get_the_optiml(step, world.optiml['resource'])
-        status = get_status(world.optiml)
-    eq_(status['code'], int(code1))
+    world.optiml = wait_until_status_code_is(code1, code2, secs, world.optiml)
 
 #@step(r'I wait until the optiml is ready less than (\d+)')
 def the_optiml_is_finished_in_less_than(step, secs):
@@ -426,18 +419,7 @@ def i_create_a_fusion_with_objective_and_params(step, objective, parms=None):
 
 #@step(r'I wait until the fusion status code is either (\d) or (-\d) less than (\d+)')
 def wait_until_fusion_status_code_is(step, code1, code2, secs):
-    start = datetime.utcnow()
-    delta = int(secs) * world.delta
-    read.i_get_the_fusion(step, world.fusion['resource'])
-    status = get_status(world.fusion)
-    count = 0
-    while (status['code'] != int(code1) and
-           status['code'] != int(code2)):
-        count += 1
-        logged_wait(start, delta, count, "fusion")
-        read.i_get_the_fusion(step, world.fusion['resource'])
-        status = get_status(world.fusion)
-    eq_(status['code'], int(code1))
+    world.fusion = wait_until_status_code_is(code1, code2, secs, world.fusion)
 
 #@step(r'I wait until the fusion is ready less than (\d+)')
 def the_fusion_is_finished_in_less_than(step, secs):
@@ -552,20 +534,26 @@ def check_linear_regression_id_local_id(step):
     eq_(world.local_linear_regression.resource_id,
         world.linear_regression["resource"])
 
+
 def local_logistic_prediction_is(step, input_data, prediction):
     eq_(world.local_logistic.predict(input_data), prediction)
 
 def local_linear_prediction_is(step, input_data, prediction):
-    eq_(world.local_linear_regression.predict(input_data), prediction)
+    world.eq_(world.local_linear_regression.predict(input_data),
+              prediction,
+              precision=5)
 
 def local_deepnet_prediction_is(step, input_data, prediction):
-    eq_(world.local_deepnet.predict(input_data), prediction)
+    world.eq_(world.local_deepnet.predict(input_data), prediction,
+              precision=4)
 
 def local_ensemble_prediction_is(step, input_data, prediction):
-    eq_(world.local_ensemble.predict(input_data), prediction)
+    world.eq_(world.local_ensemble.predict(input_data), prediction,
+              precision=5)
 
 def local_model_prediction_is(step, input_data, prediction):
-    eq_(world.local_model.predict(input_data), prediction)
+    world.eq_(world.local_model.predict(input_data), prediction,
+              precision=5)
 
 def local_cluster_prediction_is(step, input_data, prediction):
     eq_(world.local_cluster.centroid(input_data), prediction)
@@ -578,3 +566,47 @@ def local_association_prediction_is(step, input_data, prediction):
 
 def local_time_series_prediction_is(step, input_data, prediction):
     eq_(world.local_time_series.centroid(input_data), prediction)
+
+
+#@step(r'I clone model')
+def clone_model(step, model):
+    resource = world.api.clone_model(model, {'project': world.project_id})
+    # update status
+    world.status = resource['code']
+    world.location = resource['location']
+    world.model = resource['object']
+    # save reference
+    world.models.append(resource['resource'])
+
+def the_cloned_model_is(step, model):
+    eq_(world.model["origin"], model)
+
+
+#@step(r'I clone deepnet')
+def clone_deepnet(step, deepnet):
+    resource = world.api.clone_deepnet(deepnet, {'project': world.project_id})
+    # update status
+    world.status = resource['code']
+    world.location = resource['location']
+    world.deepnet = resource['object']
+    # save reference
+    world.deepnets.append(resource['resource'])
+
+
+def the_cloned_deepnet_is(step, deepnet):
+    eq_(world.deepnet["origin"], deepnet)
+
+
+#@step(r'I clone logistic regression')
+def clone_logistic_regression(step, logistic_regression):
+    resource = world.api.clone_logistic_regression(
+        logistic_regression, {'project': world.project_id})
+    # update status
+    world.status = resource['code']
+    world.location = resource['location']
+    world.logistic_regression = resource['object']
+    # save reference
+    world.logistic_regressions.append(resource['resource'])
+
+def the_cloned_logistic_regression_is(step, logistic_regression):
+    eq_(world.logistic_regression["origin"], logistic_regression)
