@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 #
-# Copyright 2018-2021 BigML
+# Copyright 2018-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -28,7 +28,7 @@ from bigml.api import FINISHED
 from bigml.api import FAULTY
 from bigml.api import get_status
 
-from .read_pca_steps import i_get_the_pca
+from .read_resource_steps import wait_until_status_code_is
 
 
 #@step(r'the pca name is "(.*)"')
@@ -37,14 +37,15 @@ def i_check_pca_name(step, name):
     eq_(name, pca_name)
 
 #@step(r'I create a PCA from a dataset$')
-def i_create_a_pca_from_dataset(step):
-    dataset = world.dataset.get('resource')
-    resource = world.api.create_pca(dataset, {'name': 'new PCA'})
-    world.status = resource['code']
-    eq_(world.status, HTTP_CREATED)
-    world.location = resource['location']
-    world.pca = resource['object']
-    world.pcas.append(resource['resource'])
+def i_create_a_pca_from_dataset(step, shared=None):
+    if shared is None or world.shared.get("pca", {}).get(shared) is None:
+        dataset = world.dataset.get('resource')
+        resource = world.api.create_pca(dataset, {'name': 'new PCA'})
+        world.status = resource['code']
+        eq_(world.status, HTTP_CREATED)
+        world.location = resource['location']
+        world.pca = resource['object']
+        world.pcas.append(resource['resource'])
 
 
 #@step(r'I create a PCA from a dataset$')
@@ -58,8 +59,8 @@ def i_create_a_pca_with_params(step, params):
     world.pca = resource['object']
     world.pcas.append(resource['resource'])
 
-def i_create_a_pca(step):
-    i_create_a_pca_from_dataset(step)
+def i_create_a_pca(step, shared=None):
+    i_create_a_pca_from_dataset(step, shared=shared)
 
 
 #@step(r'I update the PCA name to "(.*)"$')
@@ -74,22 +75,32 @@ def i_update_pca_name(step, name):
 
 #@step(r'I wait until the PCA status code is either (\d) or (-\d) less than (\d+)')
 def wait_until_pca_status_code_is(step, code1, code2, secs):
-    start = datetime.utcnow()
-    delta = int(secs) * world.delta
-    pca_id = world.pca['resource']
-    i_get_the_pca(step, pca_id)
-    status = get_status(world.pca)
-    count = 0
-    while (status['code'] != int(code1) and
-           status['code'] != int(code2)):
-        count += 1
-        logged_wait(start, delta, count, "pca")
-        assert_less((datetime.utcnow() - start).seconds, delta)
-        i_get_the_pca(step, pca_id)
-        status = get_status(world.pca)
-    eq_(status['code'], int(code1))
+    world.pca = wait_until_status_code_is(code1, code2, secs, world.pca)
 
 
 #@step(r'I wait until the PCA is ready less than (\d+)')
-def the_pca_is_finished_in_less_than(step, secs):
-    wait_until_pca_status_code_is(step, FINISHED, FAULTY, secs)
+def the_pca_is_finished_in_less_than(step, secs, shared=None):
+    if shared is None or world.shared.get("pca", {}).get(shared) is None:
+        wait_until_pca_status_code_is(step, FINISHED, FAULTY, secs)
+        if shared is not None:
+            if "pca" not in world.shared:
+                world.shared["pca"] = {}
+            world.shared["pca"][shared] = world.pca
+    else:
+        world.pca = world.shared["pca"][shared]
+        print("Reusing %s" % world.pca["resource"])
+
+
+#@step(r'I clone pca')
+def clone_pca(step, pca):
+    resource = world.api.clone_pca(pca,
+                                   {'project': world.project_id})
+    # update status
+    world.status = resource['code']
+    world.location = resource['location']
+    world.pca = resource['object']
+    # save reference
+    world.pcas.append(resource['resource'])
+
+def the_cloned_pca_is(step, pca):
+    eq_(world.pca["origin"], pca)
