@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 #
-# Copyright 2015-2021 BigML
+# Copyright 2015-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -20,12 +20,12 @@ import time
 from nose.tools import assert_almost_equals, eq_, assert_is_not_none, \
     assert_less
 from datetime import datetime
-from .world import world, logged_wait
+from .world import world, res_filename
 from bigml.api import HTTP_CREATED
 from bigml.api import FINISHED, FAULTY
 from bigml.api import get_status
 
-from .read_prediction_steps import i_get_the_prediction
+from .read_resource_steps import wait_until_status_code_is
 
 def i_create_a_prediction(step, data=None):
     if data is None:
@@ -112,18 +112,19 @@ def i_create_a_proportional_prediction(step, data=None):
     world.predictions.append(resource['resource'])
 
 
-def check_prediction(got, expected):
+def check_prediction(got, expected, precision=4):
     if not isinstance(got, str):
-        assert_almost_equals(got, float(expected), 4)
+        assert_almost_equals(got, float(expected), precision)
     else:
         eq_(got, expected)
 
-def the_prediction_is(step, objective, prediction):
-    check_prediction(world.prediction['prediction'][objective], prediction)
+def the_prediction_is(step, objective, prediction, precision=4):
+    check_prediction(world.prediction['prediction'][objective], prediction,
+                     precision=precision)
 
-def the_median_prediction_is(step, objective, prediction):
+def the_median_prediction_is(step, objective, prediction, precision=4):
     check_prediction(world.prediction['prediction_path'][
-        'objective_summary']['median'], prediction)
+        'objective_summary']['median'], prediction, precision=precision)
 
 def the_centroid_is_with_distance(step, centroid, distance):
     check_prediction(world.centroid['centroid_name'], centroid)
@@ -172,20 +173,8 @@ def i_create_an_ensemble_proportional_prediction(step, data=None, params=None):
 
 
 def wait_until_prediction_status_code_is(step, code1, code2, secs):
-    start = datetime.utcnow()
-    delta = int(secs) * world.delta
-    i_get_the_prediction(step, world.prediction['resource'])
-    status = get_status(world.prediction)
-    count = 0
-    while (status['code'] != int(code1) and
-           status['code'] != int(code2)):
-        count += 1
-        logged_wait(start, delta, count, "prediction")
-        assert_less((datetime.utcnow() - start).seconds, delta)
-        i_get_the_prediction(step, world.prediction['resource'])
-        status = get_status(world.prediction)
-    eq_(status['code'], int(code1))
-
+    world.prediction = wait_until_status_code_is(
+        code1, code2, secs, world.prediction)
 
 def the_prediction_is_finished_in_less_than(step, secs):
     wait_until_prediction_status_code_is(step, FINISHED, FAULTY, secs)
@@ -268,16 +257,25 @@ def i_create_a_logistic_prediction(step, data=None):
     world.prediction = resource['object']
     world.predictions.append(resource['resource'])
 
-def i_create_a_deepnet_prediction(step, data=None):
+def i_create_a_deepnet_prediction(step, data=None, image_fields=None):
     if data is None:
         data = "{}"
+    if image_fields is None:
+        image_fields = []
     deepnet = world.deepnet['resource']
     data = json.loads(data)
+    data_image_fields = []
+    for field in image_fields:
+        if field in data:
+            data[field] = res_filename(data[field])
+            data_image_fields.append(field)
     resource = world.api.create_prediction(deepnet, data)
     world.status = resource['code']
     eq_(world.status, HTTP_CREATED)
     world.location = resource['location']
     world.prediction = resource['object']
+    for field in data_image_fields:
+        world.sources.append(world.prediction["input_data"][field])
     world.predictions.append(resource['resource'])
 
 def i_create_a_deepnet_prediction_with_op(step, data=None,
@@ -295,6 +293,21 @@ def i_create_a_deepnet_prediction_with_op(step, data=None,
     world.predictions.append(resource['resource'])
 
 
+def i_create_a_logistic_prediction_with_op(step, data=None,
+                                           operating_point=None):
+    if data is None:
+        data = "{}"
+    logistic_regression = world.logistic_regression['resource']
+    data = json.loads(data)
+    resource = world.api.create_prediction( \
+        logistic_regression, data, {"operating_point": operating_point})
+    world.status = resource['code']
+    eq_(world.status, HTTP_CREATED)
+    world.location = resource['location']
+    world.prediction = resource['object']
+    world.predictions.append(resource['resource'])
+
+
 def the_logistic_probability_is(step, probability):
     for [prediction, remote_probability] in world.prediction['probabilities']:
         if prediction == world.prediction['output']:
