@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 #
-# Copyright 2015-2021 BigML
+# Copyright 2015-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -19,7 +19,7 @@ import time
 import json
 import os
 from datetime import datetime
-from .world import world, logged_wait
+from .world import world
 from nose.tools import eq_, assert_less
 
 from bigml.api import HTTP_CREATED
@@ -28,7 +28,7 @@ from bigml.api import FINISHED
 from bigml.api import FAULTY
 from bigml.api import get_status
 
-from .read_sample_steps import i_get_the_sample
+from .read_resource_steps import wait_until_status_code_is
 
 
 #@step(r'the sample name is "(.*)"')
@@ -57,24 +57,7 @@ def i_update_sample_name(step, name):
     world.sample = resource['object']
 
 
-#@step(r'I wait until the sample status code is either (\d) or (-\d) less than (\d+)')
-def wait_until_sample_status_code_is(step, code1, code2, secs):
-    start = datetime.utcnow()
-    delta = int(secs) * world.delta
-    sample_id = world.sample['resource']
-    i_get_the_sample(step, sample_id)
-    status = get_status(world.sample)
-    count = 0
-    while (status['code'] != int(code1) and
-           status['code'] != int(code2)):
-        count += 1
-        logged_wait(start, delta, count, "sample")
-        assert_less((datetime.utcnow() - start).seconds, delta)
-        i_get_the_sample(step, sample_id)
-        status = get_status(world.sample)
-    eq_(status['code'], int(code1))
-
-
 #@step(r'I wait until the sample is ready less than (\d+)')
 def the_sample_is_finished_in_less_than(step, secs):
-    wait_until_sample_status_code_is(step, FINISHED, FAULTY, secs)
+    world.sample = wait_until_status_code_is(
+        FINISHED, FAULTY, secs, world.sample)
