@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 #
-# Copyright 2012, 2015-2021 BigML
+# Copyright 2012, 2015-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -18,11 +18,10 @@
 import time
 import json
 import csv
-import sys
 
 
 from datetime import datetime
-from .world import world, res_filename, logged_wait
+from .world import world, res_filename
 from nose.tools import eq_, assert_less
 
 from bigml.api import HTTP_CREATED, HTTP_ACCEPTED
@@ -32,11 +31,12 @@ from bigml.api import UPLOADING
 from bigml.api import get_status
 
 
-from . import read_source_steps as read
+from .read_resource_steps import wait_until_status_code_is
+
 
 #@step(r'I create a data source uploading a "(.*)" file$')
 def i_upload_a_file(step, file, shared=None):
-    if shared is None or step.shared.get(shared, {}).get("source") is None:
+    if shared is None or world.shared.get("source", {}).get(shared) is None:
         resource = world.api.create_source(res_filename(file), \
             {'project': world.project_id})
         # update status
@@ -102,12 +102,49 @@ def i_create_using_connector(step, connector):
     # save reference
     world.sources.append(resource['resource'])
 
+#@step(r'I create from list of sources ".*"')
+def i_create_composite(step, sources):
+    resource = world.api.create_source(sources, {'project': world.project_id})
+    # update status
+    world.status = resource['code']
+    world.location = resource['location']
+    world.source = resource['object']
+    # save reference
+    world.composites.append(resource['resource'])
+
+def the_composite_contains(step, sources):
+    eq_(world.source["sources"], sources)
+
+#@step(r'I clone source')
+def clone_source(step, source):
+    resource = world.api.clone_source(source, {'project': world.project_id})
+    # update status
+    world.status = resource['code']
+    world.location = resource['location']
+    world.source = resource['object']
+    # save reference
+    world.sources.append(resource['resource'])
+
+def the_cloned_source_origin_is(step, source):
+    eq_(world.source["origin"], source)
+
+def i_create_annotated_source(step, directory, args=None):
+    if args is None:
+        args = {}
+    args.update({'project': world.project_id})
+    resource = world.api.create_annotated_source(res_filename(directory),
+                                                 args)
+    # update status
+    world.status = resource['code']
+    world.location = resource['location']
+    world.source = resource['object']
+    # save reference
+    world.composites.append(resource['resource'])
+
 #@step(r'I create a data source from inline data slurped from "(.*)"')
 def i_create_using_dict_data(step, data):
     # slurp CSV file to local variable
-    mode = 'rb'
-    if sys.version > '3':
-        mode = 'rt'
+    mode = 'rt'
     with open(res_filename(data), mode) as fid:
         reader = csv.DictReader(fid)
         dict_data = [row for row in reader]
@@ -130,49 +167,25 @@ def i_upload_a_file_async(step, file):
 
 #@step(r'I wait until the source has been created less than (\d+) secs')
 def the_source_has_been_created_async(step, secs):
-    start = datetime.utcnow()
-    read.i_get_the_source(step, world.source['resource'])
-    status = get_status(world.resource)
-    count = 0
-    delta = int(secs) * world.delta
-    while status['code'] == UPLOADING:
-        count += 1
-        logged_wait(start, delta, count, "source")
-        read.i_get_the_source(step, world.source['resource'])
-        status = get_status(world.source)
-    eq_(world.resource['code'], HTTP_CREATED)
-    # update status
-    world.status = world.resource['code']
-    world.location = world.resource['location']
-    world.source = world.resource['object']
-    # save reference
-    world.sources.append(world.resource['resource'])
+    world.source = wait_until_status_code_is(code1, code2, secs, world.source)
+
 
 #@step(r'I wait until the source status code is either (\d) or (\d) less than (\d+)')
 def wait_until_source_status_code_is(step, code1, code2, secs):
-    start = datetime.utcnow()
-    delta = int(secs) * world.delta
-    read.i_get_the_source(step, world.source['resource'])
-    status = get_status(world.source)
-    count = 0
-    while (status['code'] != int(code1) and
-           status['code'] != int(code2)):
-        count += 1
-        logged_wait(start, delta, count, "source")
-        read.i_get_the_source(step, world.source['resource'])
-        status = get_status(world.source)
-    eq_(status['code'], int(code1))
+    world.source = wait_until_status_code_is(code1, code2, secs, world.source)
+
 
 #@step(r'I wait until the source is ready less than (\d+)')
 def the_source_is_finished(step, secs, shared=None):
-    if shared is None or step.shared.get(shared, {}).get("source") is None:
+    if shared is None or world.shared.get("source", {}).get(shared) is None:
         wait_until_source_status_code_is(step, FINISHED, FAULTY, secs)
         if shared is not None:
-            if step.shared.get(shared) is None:
-                step.shared[shared] = {}
-            step.shared[shared]["source"] = world.source
+            if world.shared.get("source") is None:
+                world.shared["source"] = {}
+            world.shared["source"][shared] = world.source
     else:
-        world.source = step.shared[shared]["source"]
+        world.source = world.shared["source"][shared]
+        print("Reusing %s" % world.source["resource"])
 
 #@step(r'I update the source with params "(.*)"')
 def i_update_source_with(step, data="{}"):
