@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2017-2021 BigML
+# Copyright 2017-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -19,7 +19,7 @@ import json
 import os
 from nose.tools import eq_, assert_less
 from datetime import datetime
-from .world import world, res_filename, logged_wait
+from .world import world, res_filename
 
 from bigml.api import HTTP_OK
 from bigml.api import HTTP_CREATED
@@ -29,7 +29,7 @@ from bigml.api import FAULTY
 from bigml.api import get_status
 from bigml.timeseries import TimeSeries
 
-from . import read_time_series_steps as read
+from .read_resource_steps import wait_until_status_code_is
 
 
 #@step(r'I create a time series$')
@@ -55,25 +55,11 @@ def i_create_a_time_series_with_params(step, data="{}"):
     world.time_series_set.append(resource['resource'])
 
 
-#@step(r'I wait until the time series status code is either (\d) or (-\d) less than (\d+)')
-def wait_until_time_series_status_code_is(step, code1, code2, secs):
-    start = datetime.utcnow()
-    delta = int(secs) * world.delta
-    read.i_get_the_time_series(step, world.time_series['resource'])
-    status = get_status(world.time_series)
-    count = 0
-    while (status['code'] != int(code1) and
-           status['code'] != int(code2)):
-        count += 1
-        logged_wait(start, delta, count, "timeseries")
-        assert_less((datetime.utcnow() - start).seconds, delta)
-        read.i_get_the_time_series(step, world.time_series['resource'])
-        status = get_status(world.time_series)
-    eq_(status['code'], int(code1))
 
 #@step(r'I wait until the time series is ready less than (\d+)')
 def the_time_series_is_finished_in_less_than(step, secs):
-    wait_until_time_series_status_code_is(step, FINISHED, FAULTY, secs)
+    world.time_series = wait_until_status_code_is(
+        FINISHED, FAULTY, secs, world.time_series)
 
 
 #@step(r'I create a local TimeSeries$')
@@ -111,3 +97,17 @@ def i_create_local_time_series_from_file(step, export_file):
 #@step(r'the time series ID and the local time series ID match')
 def check_time_series_id_local_id(step):
     eq_(world.local_time_series.resource_id, world.time_series["resource"])
+
+#@step(r'I clone time series')
+def clone_time_series(step, time_series):
+    resource = world.api.clone_time_series(time_series,
+                                           {'project': world.project_id})
+    # update status
+    world.status = resource['code']
+    world.location = resource['location']
+    world.time_series = resource['object']
+    # save reference
+    world.time_series_set.append(resource['resource'])
+
+def the_cloned_time_series_is(step, time_series):
+    eq_(world.time_series["origin"], time_series)
