@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012-2021 BigML
+# Copyright 2012-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -21,13 +21,6 @@ from bigml.api import HTTP_OK
 from bigml.fields import Fields
 from nose.tools import eq_, assert_not_equal
 
-#@step(r'I get the dataset "(.*)"')
-def i_get_the_dataset(step, dataset):
-    resource = world.api.get_dataset(dataset)
-    world.status = resource['code']
-    eq_(world.status, HTTP_OK)
-    world.dataset = resource['object']
-
 
 #@step(r'I ask for the missing values counts in the fields')
 def i_get_the_missing_values(step):
