@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2015-2021 BigML
+# Copyright 2015-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -18,7 +18,10 @@
 """ Testing MultiVote predictions
 
 """
-from .world import world, setup_module, teardown_module
+import sys
+
+from .world import world, setup_module, teardown_module, show_doc, \
+    show_method, delete_local
 from . import compute_multivote_prediction_steps as multivote_prediction
 
 
@@ -34,28 +37,21 @@ class TestMultiVotePrediction(object):
         """
             Debug information
         """
+        delete_local()
         print("\nEnd of tests in: %s\n-------------------\n" % __name__)
 
     def test_scenario1(self):
         """
-            Scenario: Successfully computing predictions combinations:
+            Scenario 1: Successfully computing predictions combinations:
                 Given I create a MultiVote for the set of predictions in file <predictions>
                 When I compute the prediction with confidence using method "<method>"
                 And I compute the prediction without confidence using method "<method>"
                 Then the combined prediction is "<prediction>"
                 And the combined prediction without confidence is "<prediction>"
                 And the confidence for the combined prediction is <confidence>
-
-                Examples:
-                | predictions               | method       | prediction    | confidence            |
-                | ../data/predictions_c.json| 0            | a             | 0.45047        |
-                | ../data/predictions_c.json| 1            | a             | 0.55202        |
-                | ../data/predictions_c.json| 2            | a             | 0.40363        |
-                | ../data/predictions_r.json| 0            | 1.55555556667 | 0.40008        |
-                | ../data/predictions_r.json| 1            | 1.59376845074 | 0.24837        |
-                | ../data/predictions_r.json| 2            | 1.55555556667 | 0.40008        |
         """
-        print(self.test_scenario1.__doc__)
+        show_doc(self.test_scenario1)
+        headers = ["predictions_file", "method", "prediction", "confidence"]
         examples = [
             ['data/predictions_c.json', '0', 'a', '0.45047'],
             ['data/predictions_c.json', '1', 'a', '0.55202'],
@@ -64,10 +60,17 @@ class TestMultiVotePrediction(object):
             ['data/predictions_r.json', '1', '1.59376845074', '0.24837'],
             ['data/predictions_r.json', '2', '1.55555556667', '0.40008']]
         for example in examples:
-            print("\nTesting with:\n", example)
-            multivote_prediction.i_create_a_multivote(self, example[0])
-            multivote_prediction.compute_prediction(self, example[1])
-            multivote_prediction.compute_prediction_no_confidence(self, example[1])
-            multivote_prediction.check_combined_prediction(self, example[2])
-            multivote_prediction.check_combined_prediction_no_confidence(self, example[2])
-            multivote_prediction.check_combined_confidence(self, example[3])
+            example = dict(zip(headers, example))
+            show_method(self, sys._getframe().f_code.co_name, example)
+            multivote_prediction.i_create_a_multivote(
+                self, example["predictions_file"])
+            multivote_prediction.compute_prediction(
+            self, example["method"])
+            multivote_prediction.compute_prediction_no_confidence(
+                self, example["method"])
+            multivote_prediction.check_combined_prediction(
+                self, example["prediction"])
+            multivote_prediction.check_combined_prediction_no_confidence(
+                self, example["prediction"])
+            multivote_prediction.check_combined_confidence(
+                self, example["confidence"])
