@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2015-2021 BigML
+# Copyright 2015-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -18,7 +18,10 @@
 """ Creating model on lists of datasets
 
 """
-from .world import world, setup_module, teardown_module
+import sys
+
+from .world import world, setup_module, teardown_module, show_doc, \
+    show_method, delete_local
 from . import create_source_steps as source_create
 from . import create_dataset_steps as dataset_create
 from . import create_model_steps as model_create
@@ -37,6 +40,7 @@ class TestMultimodel(object):
         """
             Debug information
         """
+        delete_local()
         print("\nEnd of tests in: %s\n-------------------\n" % __name__)
 
     def test_scenario1(self):
@@ -53,26 +57,29 @@ class TestMultimodel(object):
                 Then I create a model from a dataset list
                 And I wait until the model is ready less than <time_4> secs
                 And I check the model stems from the original dataset list
-
-                Examples:
-                | data                | time_1  | time_2 | time_3 |  time_4 |
-                | ../data/iris.csv | 10      | 10     | 10     |  10
         """
-        print(self.test_scenario1.__doc__)
+        show_doc(self.test_scenario1)
+        headers = ["data", "source_wait", "dataset_wait", "model_wait"]
         examples = [
-            ['data/iris.csv', '10', '10', '10', '10']]
+            ['data/iris.csv', '10', '10', '10']]
         for example in examples:
-            print("\nTesting with:\n", example)
-            source_create.i_upload_a_file(self, example[0])
-            source_create.the_source_is_finished(self, example[1])
-            dataset_create.i_create_a_dataset(self)
-            dataset_create.the_dataset_is_finished_in_less_than(self, example[2])
+            example = dict(zip(headers, example))
+            show_method(self, sys._getframe().f_code.co_name, example)
+            source_create.i_upload_a_file(
+                self, example["data"], shared=example["data"])
+            source_create.the_source_is_finished(
+                self, example["source_wait"], shared=example["data"])
+            dataset_create.i_create_a_dataset(self, shared=example["data"])
+            dataset_create.the_dataset_is_finished_in_less_than(
+                self, example["dataset_wait"], shared=example["data"])
             multimodel_create.i_store_dataset_id(self)
             dataset_create.i_create_a_dataset(self)
-            dataset_create.the_dataset_is_finished_in_less_than(self, example[3])
+            dataset_create.the_dataset_is_finished_in_less_than(
+                self, example["dataset_wait"])
             multimodel_create.i_store_dataset_id(self)
             model_create.i_create_a_model_from_dataset_list(self)
-            model_create.the_model_is_finished_in_less_than(self, example[4])
+            model_create.the_model_is_finished_in_less_than(
+                self, example["model_wait"])
             multimodel_create.i_check_model_datasets_and_datasets_ids(self)
 
     def test_scenario2(self):
@@ -87,23 +94,29 @@ class TestMultimodel(object):
                 And I create a local multi model
                 When I create a local multimodel batch prediction using median for <input_data>
                 Then the local prediction is <prediction>
-
-                Examples:
-                | data                | time_1  | time_2 | time_3 |  input_data | prediction
-                | ../data/grades.csv | 10      | 10     | 10     |  {'Tutorial': 99.47, 'Midterm': 53.12, 'TakeHome': 87.96} | 50
         """
-        print(self.test_scenario2.__doc__)
+        show_doc(self.test_scenario2)
+        headers = ["data", "source_wait", "dataset_wait", "model_wait",
+                   "input_data", "prediction"]
         examples = [
-            ['data/grades.csv', '30', '30', '30', '{"Tutorial": 99.47, "Midterm": 53.12, "TakeHome": 87.96}', 63.33]]
+            ['data/grades.csv', '30', '30', '30',
+             '{"Tutorial": 99.47, "Midterm": 53.12, "TakeHome": 87.96}',
+             63.33]]
         for example in examples:
-            print("\nTesting with:\n", example)
-            source_create.i_upload_a_file(self, example[0])
-            source_create.the_source_is_finished(self, example[1])
-            dataset_create.i_create_a_dataset(self)
-            dataset_create.the_dataset_is_finished_in_less_than(self, example[2])
-            model_create.i_create_a_model(self)
-            model_create.the_model_is_finished_in_less_than(self, example[3])
+            example = dict(zip(headers, example))
+            show_method(self, sys._getframe().f_code.co_name, example)
+            source_create.i_upload_a_file(
+                self, example["data"], shared=example["data"])
+            source_create.the_source_is_finished(
+                self, example["source_wait"], shared=example["data"])
+            dataset_create.i_create_a_dataset(self, shared=example["data"])
+            dataset_create.the_dataset_is_finished_in_less_than(
+                self, example["dataset_wait"], shared=example["data"])
+            model_create.i_create_a_model(self, shared=example["data"])
+            model_create.the_model_is_finished_in_less_than(
+                self, example["model_wait"], shared=example["data"])
             world.list_of_models = [world.model]
             compare_pred.i_create_a_local_multi_model(self)
-            compare_pred.i_create_a_local_mm_median_batch_prediction(self, example[4])
-            compare_pred.the_local_prediction_is(self, example[5])
+            compare_pred.i_create_a_local_mm_median_batch_prediction(
+                self, example["input_data"])
+            compare_pred.the_local_prediction_is(self, example["prediction"])
