@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2015-2021 BigML
+# Copyright 2015-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -18,7 +18,10 @@
 """ Splitting dataset
 
 """
-from .world import world, setup_module, teardown_module
+import sys
+
+from .world import world, setup_module, teardown_module, show_doc, \
+    show_method, delete_local
 from . import create_source_steps as source_create
 from . import create_dataset_steps as dataset_create
 
@@ -34,36 +37,38 @@ class TestSplitDataset(object):
         """
             Debug information
         """
+        delete_local()
         print("\nEnd of tests in: %s\n-------------------\n" % __name__)
 
     def test_scenario1(self):
         """
             Scenario: Successfully creating a split dataset:
                 Given I create a data source with "<params>" uploading a "<data>" file
-                And I wait until the source is ready less than <time_1> secs
+                And I wait until the source is ready less than <source_wait> secs
                 And I create a dataset
-                And I wait until the dataset is ready less than <time_2> secs
+                And I wait until the dataset is ready less than <dataset_wait> secs
                 And I create a dataset extracting a <rate> sample
-                And I wait until the dataset is ready less than <time_3> secs
+                And I wait until the dataset is ready less than <dataset_wait> secs
                 When I compare the datasets' instances
                 Then the proportion of instances between datasets is <rate>
-
-                Examples:
-                | data                | time_1  | time_2 | time_3 | rate |
-                | ../data/iris.csv | 10      | 10     | 10     | 0.8 |
         """
-        print(self.test_scenario1.__doc__)
+        show_doc(self.test_scenario1)
+        headers = ["data", "source_wait", "dataset_wait", "model_wait",
+                   "rate", "source_conf"]
         examples = [
             ['data/iris.csv', '10', '10', '10', '0.8', '{"category": 12}']]
         for example in examples:
-            print("\nTesting with:\n", example)
-            source_create.i_upload_a_file_with_args(self, example[0], example[5])
-            source_create.the_source_is_finished(self, example[1])
+            example = dict(zip(headers, example))
+            show_method(self, sys._getframe().f_code.co_name, example)
+            source_create.i_upload_a_file_with_args(
+                self, example["data"], example["source_conf"])
+            source_create.the_source_is_finished(
+                self, example["source_wait"])
             dataset_create.i_create_a_dataset(self)
-            dataset_create.the_dataset_is_finished_in_less_than(self,
-                                                                example[2])
-            dataset_create.i_create_a_split_dataset(self, example[4])
-            dataset_create.the_dataset_is_finished_in_less_than(self,
-                                                                example[3])
+            dataset_create.the_dataset_is_finished_in_less_than(
+                self, example["dataset_wait"])
+            dataset_create.i_create_a_split_dataset(self, example["rate"])
+            dataset_create.the_dataset_is_finished_in_less_than(
+                self, example["dataset_wait"])
             dataset_create.i_compare_datasets_instances(self)
-            dataset_create.proportion_datasets_instances(self, example[4])
+            dataset_create.proportion_datasets_instances(self, example["rate"])
