@@ -576,257 +576,6 @@ class TestComparePrediction(object):
                 self, example["prediction"])
 
     def test_scenario11(self):
-        """
-            Scenario: Successfully comparing remote and local predictions
-                      with raw date input for linear regression:
-                Given I create a data source uploading a "<data>" file
-                And I wait until the source is ready less than <source_wait> secs
-                And I create a dataset
-                And I wait until the dataset is ready less than <dataset_wait> secs
-                And I create a linear regression
-                And I wait until the linear regression is ready
-                less than <model_wait> secs
-                And I create a local linear regression
-                When I create a prediction for "<input_data>"
-                Then the prediction for "<objective_id>" is "<prediction>"
-                And I create a local prediction for "<input_data>"
-                Then the local prediction is "<prediction>"
-        """
-        headers = ["data", "source_wait", "dataset_wait", "model_wait",
-                   "input_data", "objective_id", "prediction"]
-        examples = [
-            ['data/dates2.csv', '20', '20', '25',
-             '{"time-1": "1910-05-08T19:10:23.106", "cat-0":"cat2"}',
-             '000002',  -0.01284],
-            ['data/dates2.csv', '20', '20', '25',
-             '{"time-1": "1920-06-30T20:21:20.320", "cat-0":"cat1"}',
-             '000002', -0.09459],
-            ['data/dates2.csv', '20', '20', '25',
-             '{"time-1": "1932-01-30T19:24:11.440",  "cat-0":"cat2"}',
-             '000002', -0.02259],
-            ['data/dates2.csv', '20', '20', '25',
-             '{"time-1": "1950-11-06T05:34:05.252", "cat-0":"cat1"}',
-             '000002', -0.06754],
-            ['data/dates2.csv', '20', '20', '25',
-             '{"time-1": "2001-01-05T23:04:04.693", "cat-0":"cat2"}',
-             '000002', 0.05204],
-            ['data/dates2.csv', '20', '20', '25',
-             '{"time-1": "2011-04-01T00:16:45.747", "cat-0":"cat2"}',
-             '000002', 0.05878]]
-        show_doc(self.test_scenario11)
-
-        for example in examples:
-            example = dict(zip(headers, example))
-            show_method(self, sys._getframe().f_code.co_name, example)
-            source_create.i_upload_a_file(
-                self, example["data"], shared=example["data"])
-            source_create.the_source_is_finished(
-                self, example["source_wait"], shared=example["data"])
-            dataset_create.i_create_a_dataset(self, shared=example["data"])
-            dataset_create.the_dataset_is_finished_in_less_than(
-                self, example["dataset_wait"], shared=example["data"])
-            linear_create.i_create_a_linear_regression(
-                self, shared=example["data"])
-            linear_create.the_linear_regression_is_finished_in_less_than(
-                self, example["model_wait"], shared=example["data"])
-            prediction_compare.i_create_a_local_linear(self)
-            prediction_create.i_create_a_linear_prediction(
-                self, example["input_data"])
-            prediction_create.the_prediction_is(
-                self, example["objective_id"], example["prediction"])
-            prediction_compare.i_create_a_local_linear_prediction(
-                self, example["input_data"])
-            prediction_compare.the_local_prediction_is(
-                self, example["prediction"])
-
-    def test_scenario12(self):
-        """
-            Scenario: Successfully comparing remote and local predictions
-                      with raw date input for deepnet:
-                Given I create a data source uploading a "<data>" file
-                And I wait until the source is ready less than <source_wait> secs
-                And I create a dataset
-                And I wait until the dataset is ready less than <dataset_wait> secs
-                And I create a deepnet
-                And I wait until the deepnet is ready less than <model_wait> secs
-                And I create a local deepnet
-                When I create a prediction for "<input_data>"
-                Then the prediction for "<objective_id>" is "<prediction>"
-                And I create a local prediction for "<input_data>"
-                Then the local prediction is "<prediction>"
-        """
-        headers = ["data", "source_wait", "dataset_wait", "model_wait",
-                   "input_data", "objective_id", "prediction"]
-        examples = [
-            ['data/dates2.csv', '20', '45', '60',
-             '{"time-1": "1910-05-08T19:10:23.106", "cat-0":"cat2"}',
-             '000002', -0.02616],
-            ['data/dates2.csv', '20', '45', '60',
-             '{"time-1": "2011-04-01T00:16:45.747", "cat-0":"cat2"}',
-             '000002', 0.13352],
-            ['data/dates2.csv', '20', '45', '60',
-             '{"time-1": "1969-W29-1T17:36:39Z", "cat-0":"cat1"}',
-             '000002', 0.10071],
-            ['data/dates2.csv', '20', '45', '60',
-             '{"time-1": "1920-06-45T20:21:20.320", "cat-0":"cat1"}',
-             '000002', 0.10071],
-            ['data/dates2.csv', '20', '45', '60',
-             '{"time-1": "2001-01-05T23:04:04.693", "cat-0":"cat2"}',
-             '000002', 0.15235],
-            ['data/dates2.csv', '20', '45', '60',
-             '{"time-1": "1950-11-06T05:34:05.602", "cat-0":"cat1"}',
-             '000002', -0.07686],
-            ['data/dates2.csv', '20', '45', '60',
-             '{"time-1": "1932-01-30T19:24:11.440",  "cat-0":"cat2"}',
-             '000002', 0.0017],
-            ['data/dates2.csv', '20', '45', '60',
-             '{"time-1": "Mon Jul 14 17:36 +0000 1969", "cat-0":"cat1"}',
-             '000002', 0.10071]]
-        show_doc(self.test_scenario12)
-        for example in examples:
-            example = dict(zip(headers, example))
-            show_method(self, sys._getframe().f_code.co_name, example)
-            source_create.i_upload_a_file(
-                self, example["data"], shared=example["data"])
-            source_create.the_source_is_finished(
-                self, example["source_wait"], shared=example["data"])
-            dataset_create.i_create_a_dataset(self, shared=example["data"])
-            dataset_create.the_dataset_is_finished_in_less_than(
-                self, example["dataset_wait"])
-            deepnet_shared = "%s_no_sug" % example["data"]
-            model_create.i_create_a_no_suggest_deepnet(
-                self, shared=deepnet_shared)
-            model_create.the_deepnet_is_finished_in_less_than(
-                self, example["model_wait"], shared=deepnet_shared)
-            prediction_compare.i_create_a_local_deepnet(self)
-            prediction_create.i_create_a_deepnet_prediction(
-                self, example["input_data"])
-            prediction_create.the_prediction_is(
-                self, example["objective_id"], example["prediction"],
-                precision=4)
-            prediction_compare.i_create_a_local_deepnet_prediction(
-                self, example["input_data"])
-            prediction_compare.the_local_prediction_is(
-                self, example["prediction"], precision=4)
-
-    def test_scenario13(self):
-        """
-            Scenario: Successfully comparing remote and local predictions
-                      with raw input for deepnets with images:
-                Given I create an annotated images data source uploading a "<data>" file
-                And I wait until the source is ready less than <source_wait> secs
-                And I create a dataset
-                And I wait until the dataset is ready less than <dataset_wait> secs
-                And I create a deepnet with parms <model_conf>
-                And I wait until the deepnet is ready
-                less than <time_3> secs
-                And I create a local deepnet
-                When I create a prediction for "<input_data>"
-                Then the prediction for "<objective>" is "<prediction>"
-                And I create a local prediction for "<input_data>"
-                Then the local prediction is "<prediction>"
-                And the local probability is like the remote one
-        """
-        headers = ["data", "source_wait", "dataset_wait", "model_wait",
-                   "input_data", "objective_id", "model_conf", "image_fields"]
-        examples = [
-            ['data/images/metadata.json', '500', '500', '600',
-             '{"image_id": "data/fruits1e.jpg", "label":"f1"}',
-             '100003', {"objective_field": "100003",
-                        "number_of_hidden_layers": 1,
-                        "suggest_structure": False,
-                        "missing_numerics": True,
-                        "max_training_time": 100,
-                        "hidden_layers": [{
-                            "activation_function": "tanh",
-                            "number_of_nodes": 10}]},
-             ['image_id']]]
-        show_doc(self.test_scenario13)
-        for example in examples:
-            example = dict(zip(headers, example))
-            show_method(self, sys._getframe().f_code.co_name, example)
-            source_create.i_create_annotated_source(
-                self,
-                example["data"],
-                args={"image_analysis": {"enabled": False,
-                                         "extracted_features": []}})
-            source_create.the_source_is_finished(
-                self, example["source_wait"])
-            dataset_create.i_create_a_dataset(self)
-            dataset_create.the_dataset_is_finished_in_less_than(
-                self, example["dataset_wait"])
-            model_create.i_create_a_deepnet_with_objective_and_params(
-                self, example["objective_id"],
-                json.dumps(example["model_conf"]))
-            model_create.the_deepnet_is_finished_in_less_than(
-                self, example["model_wait"])
-            prediction_compare.i_create_a_local_deepnet(self)
-            prediction_create.i_create_a_deepnet_prediction(
-                self, example["input_data"], example["image_fields"])
-            prediction_compare.i_create_a_local_deepnet_prediction(
-                self, example["input_data"], example["image_fields"],
-                full=True)
-            prediction_create.the_prediction_is(
-                self, example["objective_id"],
-                world.local_prediction["prediction"])
-            prediction_compare.eq_local_and_remote_probability(self)
-
-    def test_scenario14(self):
-        """
-            Scenario: Successfully comparing remote and local anomaly scores
-                      with raw input for dataset with images:
-                Given I create an annotated images data source uploading a "<data>" file and <extracted_features>
-
-                And I wait until the source is ready less than <source_wait> secs
-                And I create a dataset
-                And I wait until the dataset is ready less than <dataset_wait> secs
-                And I create an anomaly detector
-                And I wait until the anomaly is ready
-                less than <anomaly_wait> secs
-                And I create a local anomaly
-                When I create an anomaly score for "<input_data>"
-                Then the anomaly score is "<score>"
-                And I create a local anomaly score for "<input_data>"
-                Then the local anomaly score is "<score>"
-        """
-        headers = ["data", "extracted_features", "source_wait", "dataset_wait",
-                   "anomaly_wait", "input_data", "score"]
-        examples = [
-            ['data/images/fruits_hist.zip',
-             ["dimensions", "average_pixels", "level_histogram",
-              "histogram_of_gradients", ["wavelet_subbands", 5],
-              ["pretrained_cnn", "mobilenetv2"]],
-              '500', '500', '600',
-             '{"image_id": "data/fruits1e.jpg"}', 0.39902]]
-        show_doc(self.test_scenario14)
-        for example in examples:
-            example = dict(zip(headers, example))
-            show_method(self, sys._getframe().f_code.co_name, example)
-            source_create.i_upload_a_file_with_args(
-                self,
-                example["data"],
-                args=json.dumps({"image_analysis": {
-                    "enabled": True,
-                    "extracted_features": example["extracted_features"]}}))
-            source_create.the_source_is_finished(
-                self, example["source_wait"])
-            dataset_create.i_create_a_dataset(self)
-            dataset_create.the_dataset_is_finished_in_less_than(
-                self, example["dataset_wait"])
-            anomaly_create.i_create_an_anomaly(self)
-            anomaly_create.the_anomaly_is_finished_in_less_than(
-                self, example["anomaly_wait"])
-            prediction_compare.i_create_a_local_anomaly(self)
-            prediction_create.i_create_an_anomaly_score(
-                self, example["input_data"])
-            prediction_compare.i_create_a_local_anomaly_score(
-                self, example["input_data"])
-            prediction_create.the_anomaly_score_is(
-                self, world.anomaly_score["score"])
-            prediction_create.the_anomaly_score_is(
-                self, example["score"])
-
-    def test_scenario15(self):
         """
             Scenario: Successfully comparing predictions for logistic regressions with operating point:
                 Given I create a data source uploading a "<data>" file
@@ -849,7 +598,7 @@ class TestComparePrediction(object):
              'Iris-versicolor', '{"default_numeric_value": "mean"}',
              {"kind": "probability", "threshold": 1,
               "positive_class": "Iris-virginica"}]]
-        show_doc(self.test_scenario3)
+        show_doc(self.test_scenario11)
         for example in examples:
             example = dict(zip(headers, example))
             show_method(self, sys._getframe().f_code.co_name, example)
