@@ -30,11 +30,18 @@ import ast
 import datetime
 
 from urllib.parse import urlparse
+from unidecode import unidecode
 
 import msgpack
 
 import bigml.constants as c
 
+try:
+    from pandas import DataFrame
+    PANDAS_READY = True
+except ImportError:
+    PANDAS_READY = False
+
 DEFAULT_LOCALE = 'en_US.UTF-8'
 WINDOWS_DEFAULT_LOCALE = 'English'
 LOCALE_SYNONYMS = {
@@ -213,12 +220,11 @@ def locale_synonyms(main_locale, locale_alias):
         return False
     alternatives = LOCALE_SYNONYMS[language_code]
     if isinstance(alternatives[0], str):
-        return main_locale in alternatives and locale_alias in alternatives
+        return locale_alias in alternatives
     result = False
     for subgroup in alternatives:
-        if main_locale in subgroup:
-            result = locale_alias in subgroup
-            break
+        result = locale_alias in subgroup
+        break
     return result
 
 
@@ -293,16 +299,65 @@ def find_locale(data_locale=DEFAULT_LOCALE, verbose=False):
                                                           new_locale))
 
 
+def asciify(name):
+    """Translating to ascii and underscores """
+
+    if len(name) == 0:
+        # case of empty name?
+        return name
+
+    name = unidecode(name).lower()
+    name = re.sub(r'\W+', '_', name)
+    return name
+
+
+def res_filename(storage_dir, resource_id, extension=None):
+    """Returns a filename from a resource id"""
+    basename = asciify(resource_id)
+    if extension is None:
+        extension = ""
+    basename = f"{basename}{extension}"
+    filename = os.path.join(storage_dir, basename)
+    return filename
+
+
+def fs_cache_get(storage_dir, minimized=True):
+    """Returns a function that retrieves a minimized resource from the file
+    system
+    """
+    extension = ".min" if minimized else ""
+    def cache_get(resource_id):
+        filename = res_filename(storage_dir, asciify(resource_id), extension)
+        if not os.path.exists(filename):
+            raise ValueError(f"Failed to find the dump file {filename}.")
+        with open(filename, "rb") as handler:
+            return handler.read()
+
+    return cache_get
+
+
+def fs_cache_set(storage_dir, minimized=True):
+    """Returns a function that stores a minimized resource in the file system """
+    extension = ".min" if minimized else ""
+    check_dir(storage_dir)
+
+    def cache_set(resource_id, msg):
+        filename = res_filename(storage_dir, asciify(resource_id), extension)
+        with open(filename, "wb") as handler:
+            handler.write(msg)
+            return filename
+
+    return cache_set
+
+
 def get_predictions_file_name(model, path):
     """Returns the file name for a multimodel predictions file
 
     """
     if isinstance(model, dict) and 'resource' in model:
         model = model['resource']
-    return "%s%s%s_%s" % (path,
-                          os.sep,
-                          model.replace("/", "_"),
-                          PREDICTIONS_FILE_SUFFIX)
+    filename = res_filename(path, model)
+    return f"{filename}_{PREDICTIONS_FILE_SUFFIX}"
 
 
 def clear_console_line(out=sys.stdout, length=PROGRESS_BAR_WIDTH):
@@ -364,6 +419,9 @@ def cast(input_data, fields):
 
     """
     for (key, value) in list(input_data.items()):
+        # inputs not in fieldsor empty
+        if key not in fields or value is None:
+            continue
         # strings given as booleans
         if isinstance(value, bool) and \
                 fields[key]['optype'] == 'categorical' and \
@@ -650,3 +708,54 @@ def is_image(filename):
     """Checking whether the file is an image based on its extension """
     return os.path.splitext(filename)[1].replace(".", "").lower() \
         in c.IMAGE_EXTENSIONS
+
+
+def get_data_format(input_data_list):
+    """Returns the format used in input_data_list: DataFrame or
+    list of dicts.
+
+    """
+    if PANDAS_READY and isinstance(input_data_list, DataFrame):
+        return c.DATAFRAME
+    if isinstance(input_data_list, list) and (len(input_data_list) == 0 or
+            isinstance(input_data_list[0], dict)):
+        return c.INTERNAL
+    raise ValueError("Data is expected to be provided as a list of "
+                     "dictionaries or Pandas' DataFrame.")
+
+#pylint: disable=locally-disabled,comparison-with-itself
+def format_data(input_data_list, out_format=None):
+    """Transforms the input data format to the one expected """
+    if out_format == c.DATAFRAME:
+        input_data_list = DataFrame.from_dict(input_data_list)
+    elif out_format == c.INTERNAL:
+        input_data_list = input_data_list.to_dict('records')
+        # pandas nan, NaN, etc. outputs need to be changed to None
+        for row in input_data_list:
+            for key, value in row.items():
+                if value != value:
+                    row[key] = None
+    return input_data_list
+
+
+def get_formatted_data(input_data_list, out_format=None):
+    """Checks the type of data and transforms if needed """
+    current_format = get_data_format(input_data_list)
+    if current_format != out_format:
+        inner_data_list = format_data(input_data_list, out_format)
+    else:
+        inner_data_list = input_data_list.copy()
+    return inner_data_list
+
+#pylint: disable=locally-disabled,import-outside-toplevel
+def get_data_transformations(resource_id, parent_id):
+    """Returns the pipeline that contains the tranformations and derived
+    features created from the raw data to the actual resource.
+
+    """
+    if parent_id is None:
+        raise ValueError("Failed to find the dataset information "
+                         "needed to buid the data transformations "
+                         "pipeline.")
+    from bigml.pipeline.pipeline import BMLPipeline
+    return BMLPipeline("dt-%s" % resource_id, [parent_id])
